# 🎯 zedmath | Math
__Simple library for mathematical expressions__

VERSION: __1.0.0__

## INSTALLATION

- __USING PIP__

```bash
pip install zedmath
```

- __CLONE REPO__

```bash
git clone https://github.com/azizbekQozoqov/
MATH.git
```


## USAGE

| Method names  | Description                   | Arguments                         |
| --------------| ------------------------------| ----------------------------------|
| pow           | Returns the power of a number | __x__ - Required - float or integer|
| abs           | Returns the absolute value of the argument | __a__ - Required - float or integer|
| round         | Round a number to a given precision in decimal digits. | __a__ - Required - float or integer |
| sum           | Returns sum of the given numbers. | __args__ - Required - integer, float, string, list[integer, float, string] |
| is_odd        | Returns given numbers is odd or non odd | __a__ - Required - integer |
| is_even       | Returns given numbers is even or non even | __a__ - Required - integer |
| ceil          | Rounds a number up to its nearest integer | __a__ - Required - integer, float |
| floor         | Returns the value of a rounded down to its nearest integer | __a__ - Required - integer, float |
| sign          | Returns given number is positive or negative using 1,-1,0 | __a__ - Required - integer, float |
| min           | Returns minimum number | __a__ - Required - integer, float |
| max           | Returns maximum number | __a__ - Required - integer, float, string, list[integer, float, string] |

